﻿using System;
using System.IO;
using System.Net;
using System.Web;
using System.Web.Script.Serialization;
using System.Web.UI;

	public partial class index : System.Web.UI.Page
	{
		private const string clientID = "";		//TODO: Insert your client-id here.
		private const string clientSecret = "";		//TODO: Insert your secret client-id here.
		private const string applicationURL = "http://apitest.exor.no/default.aspx";	//The url of this application.
		//private const string applicationURL = "http://localhost:8081/default.aspx";
		private const string scope = "read_profile create_session read_workout authorize_oauth read_master read_contact";
		private const string authPostURL = "https://auth.exorlive.com/Providers/OAuth/Token.ashx";
		private const string exorliveLibrary = "https://exorlive.com/api/bootstrapper.ashx";
		private const string loginURL = "https://auth.exorlive.com/Providers/OAuth/Authorize.aspx?response_type=code&client_id=";
		private const string jQueryLibrary = "http://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js";

		protected void Page_Load(object sender, EventArgs e)
		{
			ClientScript.RegisterClientScriptInclude("jQuery", jQueryLibrary);
			ClientScript.RegisterClientScriptInclude("ExorLive", exorliveLibrary);
			ClientScript.RegisterClientScriptInclude("ExorLiveInit", "initExorLive.js");
			ClientScript.RegisterClientScriptInclude("MiscScript", "script.js");
			string tokenCode = Request.QueryString["code"];

			// If first time at page and havent gotten a code from login...
			if (!Page.IsPostBack && String.IsNullOrEmpty(tokenCode))
			{
				Response.Redirect(loginURL + clientID + "&redirect_uri=" + applicationURL + "&scope=" + scope, false);
			}
			else
			{
				var serializer = new JavaScriptSerializer();

				//Check if the current session token has expired, if then do a POST refresh_token
				if (Session["expires_in"] != null)
				{
					DateTime tokenExpires = DateTime.Parse(Session["expires_in"].ToString());
					if (tokenExpires != null && DateTime.Compare(tokenExpires, DateTime.UtcNow) <= 0)
					{
						string postData = String.Format("grant_type=refresh_token&client_id={0}&client_secret={1}&refresh_token={2}&redirect_uri={3}", clientID, clientSecret, Session["refresh_token"], HttpUtility.UrlEncode(applicationURL));
						string result = doHttpWebRequest(authPostURL, postData, "POST");
						var resultSer = serializer.Deserialize<dynamic>(result);

						HttpContext.Current.Session["access_token"] = (string)resultSer["access_token"];
						HttpContext.Current.Session["refresh_token"] = (string)resultSer["refresh_token"];
						HttpContext.Current.Session["scope"] = (string)resultSer["scope"];
						HttpContext.Current.Session["expires_in"] = DateTime.UtcNow.AddSeconds(Convert.ToInt32((string)resultSer["expires_in"])).ToString("yyyy-MM-dd HH:mm:ss");
					}
				}
				else
				{
					string postData = String.Format("grant_type=authorization_code&client_id={0}&client_secret={1}&code={2}&redirect_uri={3}", clientID, clientSecret, tokenCode, HttpUtility.UrlEncode(applicationURL));
					string result = doHttpWebRequest(authPostURL, postData, "POST");
					var resultSer = serializer.Deserialize<dynamic>(result);

					HttpContext.Current.Session["access_token"] = (string)resultSer["access_token"];
					HttpContext.Current.Session["refresh_token"] = (string)resultSer["refresh_token"];
					HttpContext.Current.Session["scope"] = (string)resultSer["scope"];
					HttpContext.Current.Session["expires_in"] = DateTime.UtcNow.AddSeconds(Convert.ToInt32((string)resultSer["expires_in"])).ToString("yyyy-MM-dd HH:mm:ss");
				}

				//This adds a javascript global variable with all the necessary information our javascript needs.
				string jsAccessToken = String.Format("AccessToken:\"{0}\", Expiration: \"{1}\", Scope: \"{2}\"", Session["access_token"], Session["expires_in"], Session["scope"]);
				ClientScript.RegisterClientScriptBlock(this.GetType(), "access_token", "var $access_token = {" + jsAccessToken + "};", true);
			}
		}

		/// <summary>
		/// Does a HTTP web request.
		/// </summary>
		/// <param name="url">URL</param>
		/// <param name="varg">Arguments</param>
		/// <param name="method">POST or GET</param>
		/// <returns>Returns response from the request.</returns>
		private static string doHttpWebRequest(string url, string varg, string method)
		{
			string result = "";
			if (method == "GET")
			{
				url += "?" + varg;
			}
			HttpWebRequest req = (HttpWebRequest)WebRequest.Create(url);
			req.Method = method;

			if (req.Method == "POST")
			{
				req.ContentType = "application/x-www-form-urlencoded";
				// Webrequest body
				using (StreamWriter stream = new StreamWriter(req.GetRequestStream()))
				{
					stream.Write(varg);
				}
			}
			try
			{
				using (StreamReader stream = new StreamReader(req.GetResponse().GetResponseStream()))
				{
					result = stream.ReadToEnd();
				}
			}
			catch (WebException ex)
			{
				result = ex.Status.ToString();
				if (ex.Response.ContentLength != 0)
				{
					using (var stream = ex.Response.GetResponseStream())
					{
						using (var reader = new StreamReader(stream))
						{
							result += reader.ReadToEnd();
						}
					}
				}
			}
			return result;
		}
	}