﻿// This will be called once the the Exor Live framework is ready
function init_ExorLive() {

	// The two following events MUST be handled in order to complete the OAuth flow
	// This data is easily obtained serverside with not need of a library and with very little code
	// In this example 'PageMethods.RequestAccessToken' is an AJAX method calling back to the server
	ExorLive.Events.on("access.code", function (code) {
		// We pass the Grant Token to the backend so that it can exchange this for an AccessToken
		PageMethods.RequestAccessToken(code, function (accessToken) {
			// Once obtained, update the API with the new token
			ExorLive.setAccessToken(accessToken);
		});
	});

	ExorLive.Events.on("access.expired", function () {
		// passing "" instead of the Grant Token signals to the backend that we want to refresh the existing token
		PageMethods.RequestAccessToken("", function (accessToken) {
			// Once obtained, update the API with the new token
			ExorLive.setAccessToken(accessToken);
		});
	});

	// Respond to default events from the API
	ExorLive.Events.on("access.missing", function (err) {
		var el = document.getElementById("divUserProfile");
		// Display a default Authorize widget
		el.innerHTML = " <div class=\"el-widget\" data-type=\"Authorize\" data-scope=\"read_profile read_workout\">Authorize</div>";
		ExorLive.ui.widgets.parse(el);
	});

	ExorLive.Events.on("auth.success", function (profile) {
		// Display the profile data returned from Exor Live
		document.getElementById("divUserProfile").innerHTML = "Navn: " + profile.Firstname + " " + profile.Lastname + "<br/>" + "Email: " + profile.Email;
	});

	// This is where you configure the API
	ExorLive.init({
		// The culture you want used
		culture: "nb-NO",
		// Your ExorLive Applications identifier
		clientId: "apitest.exor.no",
		// In case the user needs to create an account, this will be used to populate the needed fields
		orderData: { //
			firstName: "john",
			lastName: "doe",
			email: "user@domain.example"
		},
		// If the user has already autorized you, then you can supply the token here
		/*
		accessToken: {
			// The token string
			AccessToken: "...................",
			// ISO8601 using UTC
			Expiration: "2011-09-21 12:33:10",
			// The scopes authorized through this token. This will help the API give proper feedback.
			Scope: "read_profile read_workouts ...."
		},*/
		// The accessToken was generated by the serverside and added to the html document
		// as a javascript global called $access_token.
		accessToken: typeof $access_token == "undefined" ? null : $access_token,
		// Whether the API should look for, and instantiate ExorLive Widgets
		parse: true
	});
}